@@ -6,7 +6,7 @@ def main():
         start.download_video()
         
     except KeyboardInterrupt:
-        print('[WARNING] Process interrupted with Ctrl+C.')
+        print('Process interrupted with Ctrl+C.')
 
     except Exception as e:
-        print('[ERROR]', e)
+        print('An error occured:', e)
\ No newline at end of file
